# -*- coding: utf-8 -*-
"""gds module

ImplNote:
Consider implementation here should be reusable application specific routines for GDS common use cases.
Consider not to re-do libgds SDK generality.
"""
import gzip
import logging
from tempfile import NamedTemporaryFile
from typing import List
from urllib.parse import urlparse

import boto3
import requests
from botocore.exceptions import ClientError

from libica.app import configuration
from libica.openapi import libgds

logger = logging.getLogger(__name__)


def get_gds_uri(gds_volume_name, gds_path):
    return f"gds://{gds_volume_name}{gds_path}"  # note gds path start with /


def parse_path(gds_path):
    gds_url_obj = urlparse(gds_path)
    return gds_url_obj.netloc, gds_url_obj.path


def check_file(gds_path) -> list:
    """See check_path

    NOTE: This is for "error checking" use case, hence, it may raise FileNotFoundError

    :param gds_path:
    :return:
    """
    vol, path = parse_path(gds_path)
    return check_path(vol, path)


def check_path(volume_name: str, path: str) -> list:
    """Use cases
    This behave like UNIX `ls` command whereas you can check an absolute path to file or a directory.
    You can use it to check whether a file exist in GDS because it raises FileNotFoundError.
    Otherwise, it return file(s) found.

    NOTE: This wrap get_file_list but more strict to raise FileNotFoundError if zero match.

    :param volume_name:
    :param path:
    :return: List of libgds.FileResponse objects
    :rtype: list[FileResponse]
    """

    files = get_file_list(volume_name=volume_name, path=path)
    if len(files) == 0:
        raise FileNotFoundError(f"Could not get file: gds://{volume_name}{path}")
    return files


def get_gds_file_to_bytes(gds_volume_name: str, gds_path: str) -> bytes:
    """
    get_object_to_bytes API, with on-the-fly gzip detection and decompression

    :param gds_volume_name:
    :param gds_path:
    :return bytes: bytes from the decompressed GDS File body
    """
    try:
        ntf = download_gds_file(gds_volume_name, gds_path)
        if gds_path.endswith(".gz"):
            obj_bytes = gzip.decompress(ntf.read())
        else:
            obj_bytes = ntf.read()
        ntf.close()
        return obj_bytes
    except Exception as e:
        message = f"Failed on reading the specified GDS File ({get_gds_uri(gds_volume_name, gds_path)})"
        raise FileNotFoundError(f"{message} Exception: {e}")


def get_file_list(volume_name: str, path: str = "/*") -> list:
    return get_files_list(volume_name=volume_name, paths=[path])


def get_files_list(volume_name: str, paths=None) -> list:
    """Use cases
    Get file listing for given volume_name and paths.
    If path are not specified, it will return listing of all files under given volume_name.
    Listing is recursive in nature for a volume or folder path.
    You can still specify an absolute path for a file.
    PreSignedUrl is always included.

    :param volume_name:
    :param paths: default list all
    :return: List of libgds.FileResponse objects
    :rtype: list[FileResponse]
    """

    if paths is None:
        paths = ["/*"]

    items = []

    with libgds.ApiClient(configuration(libgds)) as api_client:
        files_api = libgds.FilesApi(api_client)
        try:
            page_token = None
            while True:
                file_list: libgds.FileListResponse = files_api.list_files(
                    volume_name=[volume_name],
                    path=paths,
                    include="presignedUrl,totalItemCount",
                    page_size=1000,
                    page_token=page_token,
                )

                items.extend(file_list.items)

                page_token = file_list.next_page_token
                if not file_list.next_page_token:
                    break
            # while end

        except libgds.ApiException as e:
            logger.info("Exception when calling FilesApi: %s\n" % e)

    return items


def download_gds_file(volume_name: str, path: str) -> (NamedTemporaryFile, None):
    """Retrieve _single_ GDS file

    It collects matching path (expect single file) through get_file_list.
    Hence, there should only be one item in the list.
    Then, we use the requests library to download the gds file from presigned URL to temporary storage.
    The downloaded file is back by NamedTemporaryFile and, therefore will be deleted once it goes 'out of scope'.

    NOTE:
    It is caller responsibility to provide an absolute path to a file for the path parameter.
    If multiple files are found, it warns and return None.

    It is recommend to close NamedTemporaryFile after use.
    For example, work within closing context manager like so.
        with closing(ntf) as f:
            with open(f.name, newline='') as csv_file:
                csv_reader = csv.reader(csv_file, delimiter=',')
                ...
                ...

    :param volume_name:
    :param path: the GDS path of the file to download
    :return NamedTemporaryFile: or None if file is not found or multiple files are found
    """

    logger.info(f"Downloading file from GDS: gds://{volume_name}{path}")

    file_list = get_file_list(volume_name=volume_name, path=path)

    if not len(file_list) == 1:
        logger.warning(f"Please specify a single file. Found {len(file_list)} files at gds://{volume_name}{path}")
        return None

    if len(file_list) == 0:
        logger.warning(f"File not found: gds://{volume_name}{path}")
        return None

    file: libgds.FileResponse = file_list[0]

    gds_req = requests.get(file.presigned_url)

    ntf = NamedTemporaryFile()
    with open(ntf.name, 'wb') as f:
        f.write(gds_req.content)

    return ntf


def presign_gds_file(file_id: str, volume_name: str, path_: str, presigned_url_mode: str = "Attachment") -> (bool, str):
    with libgds.ApiClient(configuration(libgds)) as gds_client:
        files_api = libgds.FilesApi(gds_client)
        try:
            file_details: libgds.FileResponse = files_api.get_file(file_id=file_id,
                                                                   presigned_url_mode=presigned_url_mode)
            return True, file_details.presigned_url
        except libgds.ApiException as e:
            message = f"Failed to sign the specified GDS file (gds://{volume_name}{path_}). Exception - {e}"
            logger.error(message)
            return False, message


def presign_gds_file_with_override(file_id: str, **kwargs) -> (bool, str):
    """Default override option for response_content_type is text/html and response_content_disposition is inline"""
    with libgds.ApiClient(configuration(libgds)) as gds_client:
        files_api = libgds.FilesApi(gds_client)
        try:
            resp: libgds.FileResponse = files_api.update_file(file_id=file_id, include='objectStoreAccess')
            cred: libgds.AwsS3TemporaryUploadCredentials = resp.object_store_access.aws_s3_temporary_upload_credentials

            # See S3 API, "Overriding Response Header Values" section on for all possible override
            # https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

            expiration = kwargs.get('expiration', 3600)
            response_content_type = kwargs.get('response_content_type', 'text/html')
            response_content_disposition = kwargs.get('response_content_disposition', 'inline')

            s3_client = boto3.client(
                's3',
                aws_access_key_id=cred.access_key_id,
                aws_secret_access_key=cred.secret_access_key,
                aws_session_token=cred.session_token,
                region_name=cred.region,
            )

            signed_url = s3_client.generate_presigned_url(
                'get_object',
                Params={
                    'Bucket': cred.bucket_name,
                    'Key': cred.key_prefix,
                    'ResponseContentType': response_content_type,
                    'ResponseContentDisposition': response_content_disposition,
                },
                ExpiresIn=expiration)
            return True, signed_url
        except libgds.ApiException as e:
            message = f"Failed to sign the GDS file ID ({file_id}). Exception - {e}"
            logger.error(message)
            return False, message
        except ClientError as e:
            message = f"Failed to sign the GDS file ID ({file_id}). Exception - {e}"
            return False, message


def get_file_cred(file_id: str) -> (bool, libgds.AwsS3TemporaryUploadCredentials):
    """Return underlay S3 object store credential details for given GDS File ID with r+w"""
    with libgds.ApiClient(configuration(libgds)) as gds_client:
        files_api = libgds.FilesApi(gds_client)
        try:
            resp: libgds.FileResponse = files_api.update_file(file_id=file_id, include='objectStoreAccess')
            cred: libgds.AwsS3TemporaryUploadCredentials = resp.object_store_access.aws_s3_temporary_upload_credentials
            return True, cred
        except libgds.ApiException as e:
            message = f"Failed to get temporary credentials for GDS file ID ({file_id}). Exception - {e}"
            logger.error(message)
            return False, message


def get_folder_cred(folder_id: str) -> (bool, libgds.AwsS3TemporaryUploadCredentials):
    """Return underlay S3 object store credential details for given GDS Folder ID with r+w"""
    with libgds.ApiClient(configuration(libgds)) as gds_client:
        folders_api = libgds.FoldersApi(gds_client)
        try:
            resp: libgds.FolderResponse = folders_api.update_folder(folder_id=folder_id, include='objectStoreAccess')
            cred: libgds.AwsS3TemporaryUploadCredentials = resp.object_store_access.aws_s3_temporary_upload_credentials
            return True, cred
        except libgds.ApiException as e:
            message = f"Failed to get temporary credentials for GDS folder ID ({folder_id}). Exception - {e}"
            logger.error(message)
            return False, message


def get_files_from_gds_by_suffix(location: str, file_suffix: str) -> List[str]:
    """
    Use case:
        For given gds://vol/path/to/folder find file end with extension defined in file_suffix e.g. '.bam'
        Collect all found and return a list ['gds://location/1.bam', ...]
    """
    volume_name, path_ = parse_path(location)

    file_list = []

    with libgds.ApiClient(configuration(libgds)) as api_client:
        files_api = libgds.FilesApi(api_client)
        try:
            page_token = None
            while True:
                file_list_response: libgds.FileListResponse = files_api.list_files(
                    volume_name=[volume_name],
                    path=[f"{path_}/*"],
                    page_size=1000,
                    page_token=page_token,
                )

                for item in file_list_response.items:
                    file_: libgds.FileResponse = item

                    if file_.name.endswith(file_suffix):
                        file_list.append(f"gds://{file_.volume_name}{file_.path}")

                page_token = file_list_response.next_page_token
                if not file_list_response.next_page_token:
                    break
            # while end

        except libgds.ApiException as e:
            logger.error(f"Exception when calling list_files: \n{e}")

    return file_list



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class FolderWriteableResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'volume_id': 'str',
        'parent_folder_id': 'str',
        'volume_name': 'str',
        'tenant_id': 'str',
        'sub_tenant_id': 'str',
        'urn': 'str',
        'path': 'str',
        'acl': 'list[str]',
        'inherited_acl': 'list[str]',
        'time_created': 'datetime',
        'created_by': 'str',
        'time_modified': 'datetime',
        'modified_by': 'str',
        'metadata': 'object',
        'volume_metadata': 'object',
        'job_status': 'JobStatus',
        'job_id': 'str',
        'archive_job_storage_tier': 'StorageTier',
        'migration_status': 'str',
        'active_job_ids': 'list[str]',
        'copy_job_id': 'str',
        'object_store_access': 'ObjectStoreAccess'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'volume_id': 'volumeId',
        'parent_folder_id': 'parentFolderId',
        'volume_name': 'volumeName',
        'tenant_id': 'tenantId',
        'sub_tenant_id': 'subTenantId',
        'urn': 'urn',
        'path': 'path',
        'acl': 'acl',
        'inherited_acl': 'inheritedAcl',
        'time_created': 'timeCreated',
        'created_by': 'createdBy',
        'time_modified': 'timeModified',
        'modified_by': 'modifiedBy',
        'metadata': 'metadata',
        'volume_metadata': 'volumeMetadata',
        'job_status': 'jobStatus',
        'job_id': 'jobId',
        'archive_job_storage_tier': 'archiveJobStorageTier',
        'migration_status': 'migrationStatus',
        'active_job_ids': 'activeJobIds',
        'copy_job_id': 'copyJobId',
        'object_store_access': 'objectStoreAccess'
    }

    def __init__(self, id=None, name=None, volume_id=None, parent_folder_id=None, volume_name=None, tenant_id=None, sub_tenant_id=None, urn=None, path=None, acl=None, inherited_acl=None, time_created=None, created_by=None, time_modified=None, modified_by=None, metadata=None, volume_metadata=None, job_status=None, job_id=None, archive_job_storage_tier=None, migration_status=None, active_job_ids=None, copy_job_id=None, object_store_access=None, local_vars_configuration=None):  # noqa: E501
        """FolderWriteableResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._volume_id = None
        self._parent_folder_id = None
        self._volume_name = None
        self._tenant_id = None
        self._sub_tenant_id = None
        self._urn = None
        self._path = None
        self._acl = None
        self._inherited_acl = None
        self._time_created = None
        self._created_by = None
        self._time_modified = None
        self._modified_by = None
        self._metadata = None
        self._volume_metadata = None
        self._job_status = None
        self._job_id = None
        self._archive_job_storage_tier = None
        self._migration_status = None
        self._active_job_ids = None
        self._copy_job_id = None
        self._object_store_access = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if volume_id is not None:
            self.volume_id = volume_id
        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if volume_name is not None:
            self.volume_name = volume_name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if sub_tenant_id is not None:
            self.sub_tenant_id = sub_tenant_id
        if urn is not None:
            self.urn = urn
        if path is not None:
            self.path = path
        if acl is not None:
            self.acl = acl
        if inherited_acl is not None:
            self.inherited_acl = inherited_acl
        if time_created is not None:
            self.time_created = time_created
        if created_by is not None:
            self.created_by = created_by
        if time_modified is not None:
            self.time_modified = time_modified
        if modified_by is not None:
            self.modified_by = modified_by
        if metadata is not None:
            self.metadata = metadata
        if volume_metadata is not None:
            self.volume_metadata = volume_metadata
        if job_status is not None:
            self.job_status = job_status
        if job_id is not None:
            self.job_id = job_id
        if archive_job_storage_tier is not None:
            self.archive_job_storage_tier = archive_job_storage_tier
        if migration_status is not None:
            self.migration_status = migration_status
        if active_job_ids is not None:
            self.active_job_ids = active_job_ids
        if copy_job_id is not None:
            self.copy_job_id = copy_job_id
        if object_store_access is not None:
            self.object_store_access = object_store_access

    @property
    def id(self):
        """Gets the id of this FolderWriteableResponse.  # noqa: E501

        A unique identifier for this Folder  # noqa: E501

        :return: The id of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FolderWriteableResponse.

        A unique identifier for this Folder  # noqa: E501

        :param id: The id of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this FolderWriteableResponse.  # noqa: E501

        The name of this Folder  # noqa: E501

        :return: The name of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FolderWriteableResponse.

        The name of this Folder  # noqa: E501

        :param name: The name of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def volume_id(self):
        """Gets the volume_id of this FolderWriteableResponse.  # noqa: E501

        The unique identifier for this Folder's Volume  # noqa: E501

        :return: The volume_id of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """Sets the volume_id of this FolderWriteableResponse.

        The unique identifier for this Folder's Volume  # noqa: E501

        :param volume_id: The volume_id of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._volume_id = volume_id

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this FolderWriteableResponse.  # noqa: E501

        The unique identifier for this folder's parent folder  # noqa: E501

        :return: The parent_folder_id of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this FolderWriteableResponse.

        The unique identifier for this folder's parent folder  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._parent_folder_id = parent_folder_id

    @property
    def volume_name(self):
        """Gets the volume_name of this FolderWriteableResponse.  # noqa: E501

        The name of this Folder's Volume  # noqa: E501

        :return: The volume_name of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._volume_name

    @volume_name.setter
    def volume_name(self, volume_name):
        """Sets the volume_name of this FolderWriteableResponse.

        The name of this Folder's Volume  # noqa: E501

        :param volume_name: The volume_name of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._volume_name = volume_name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this FolderWriteableResponse.  # noqa: E501

        The unique identifier for this Folders's Tenant  # noqa: E501

        :return: The tenant_id of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this FolderWriteableResponse.

        The unique identifier for this Folders's Tenant  # noqa: E501

        :param tenant_id: The tenant_id of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def sub_tenant_id(self):
        """Gets the sub_tenant_id of this FolderWriteableResponse.  # noqa: E501

        The unique identifier for this Folder's Sub Tenant  # noqa: E501

        :return: The sub_tenant_id of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._sub_tenant_id

    @sub_tenant_id.setter
    def sub_tenant_id(self, sub_tenant_id):
        """Sets the sub_tenant_id of this FolderWriteableResponse.

        The unique identifier for this Folder's Sub Tenant  # noqa: E501

        :param sub_tenant_id: The sub_tenant_id of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._sub_tenant_id = sub_tenant_id

    @property
    def urn(self):
        """Gets the urn of this FolderWriteableResponse.  # noqa: E501

        The Universal Resource Name, unique to this Folder  # noqa: E501

        :return: The urn of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this FolderWriteableResponse.

        The Universal Resource Name, unique to this Folder  # noqa: E501

        :param urn: The urn of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def path(self):
        """Gets the path of this FolderWriteableResponse.  # noqa: E501

        The (GDS) folder path to this Folder  # noqa: E501

        :return: The path of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this FolderWriteableResponse.

        The (GDS) folder path to this Folder  # noqa: E501

        :param path: The path of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def acl(self):
        """Gets the acl of this FolderWriteableResponse.  # noqa: E501

        The list of directly specified Id(s) that have access to this Folder  # noqa: E501

        :return: The acl of this FolderWriteableResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this FolderWriteableResponse.

        The list of directly specified Id(s) that have access to this Folder  # noqa: E501

        :param acl: The acl of this FolderWriteableResponse.  # noqa: E501
        :type: list[str]
        """

        self._acl = acl

    @property
    def inherited_acl(self):
        """Gets the inherited_acl of this FolderWriteableResponse.  # noqa: E501

        The inherited list of Id(s) that have access to this Folder  # noqa: E501

        :return: The inherited_acl of this FolderWriteableResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._inherited_acl

    @inherited_acl.setter
    def inherited_acl(self, inherited_acl):
        """Sets the inherited_acl of this FolderWriteableResponse.

        The inherited list of Id(s) that have access to this Folder  # noqa: E501

        :param inherited_acl: The inherited_acl of this FolderWriteableResponse.  # noqa: E501
        :type: list[str]
        """

        self._inherited_acl = inherited_acl

    @property
    def time_created(self):
        """Gets the time_created of this FolderWriteableResponse.  # noqa: E501

        The date & time this Folder was created, in GDS  # noqa: E501

        :return: The time_created of this FolderWriteableResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this FolderWriteableResponse.

        The date & time this Folder was created, in GDS  # noqa: E501

        :param time_created: The time_created of this FolderWriteableResponse.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def created_by(self):
        """Gets the created_by of this FolderWriteableResponse.  # noqa: E501

        The creator of this Folder  # noqa: E501

        :return: The created_by of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this FolderWriteableResponse.

        The creator of this Folder  # noqa: E501

        :param created_by: The created_by of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def time_modified(self):
        """Gets the time_modified of this FolderWriteableResponse.  # noqa: E501

        The date & time this Folder was updated, in GDS  # noqa: E501

        :return: The time_modified of this FolderWriteableResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this FolderWriteableResponse.

        The date & time this Folder was updated, in GDS  # noqa: E501

        :param time_modified: The time_modified of this FolderWriteableResponse.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def modified_by(self):
        """Gets the modified_by of this FolderWriteableResponse.  # noqa: E501

        The updator of this Folder  # noqa: E501

        :return: The modified_by of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this FolderWriteableResponse.

        The updator of this Folder  # noqa: E501

        :param modified_by: The modified_by of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def metadata(self):
        """Gets the metadata of this FolderWriteableResponse.  # noqa: E501

        Metadata about this folder  # noqa: E501

        :return: The metadata of this FolderWriteableResponse.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this FolderWriteableResponse.

        Metadata about this folder  # noqa: E501

        :param metadata: The metadata of this FolderWriteableResponse.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def volume_metadata(self):
        """Gets the volume_metadata of this FolderWriteableResponse.  # noqa: E501

        Metadata about this folder's volume  # noqa: E501

        :return: The volume_metadata of this FolderWriteableResponse.  # noqa: E501
        :rtype: object
        """
        return self._volume_metadata

    @volume_metadata.setter
    def volume_metadata(self, volume_metadata):
        """Sets the volume_metadata of this FolderWriteableResponse.

        Metadata about this folder's volume  # noqa: E501

        :param volume_metadata: The volume_metadata of this FolderWriteableResponse.  # noqa: E501
        :type: object
        """

        self._volume_metadata = volume_metadata

    @property
    def job_status(self):
        """Gets the job_status of this FolderWriteableResponse.  # noqa: E501


        :return: The job_status of this FolderWriteableResponse.  # noqa: E501
        :rtype: JobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this FolderWriteableResponse.


        :param job_status: The job_status of this FolderWriteableResponse.  # noqa: E501
        :type: JobStatus
        """

        self._job_status = job_status

    @property
    def job_id(self):
        """Gets the job_id of this FolderWriteableResponse.  # noqa: E501

        The job identifier for the current folder operation. Currently only being used for the delete folder operation.  # noqa: E501

        :return: The job_id of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this FolderWriteableResponse.

        The job identifier for the current folder operation. Currently only being used for the delete folder operation.  # noqa: E501

        :param job_id: The job_id of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def archive_job_storage_tier(self):
        """Gets the archive_job_storage_tier of this FolderWriteableResponse.  # noqa: E501


        :return: The archive_job_storage_tier of this FolderWriteableResponse.  # noqa: E501
        :rtype: StorageTier
        """
        return self._archive_job_storage_tier

    @archive_job_storage_tier.setter
    def archive_job_storage_tier(self, archive_job_storage_tier):
        """Sets the archive_job_storage_tier of this FolderWriteableResponse.


        :param archive_job_storage_tier: The archive_job_storage_tier of this FolderWriteableResponse.  # noqa: E501
        :type: StorageTier
        """

        self._archive_job_storage_tier = archive_job_storage_tier

    @property
    def migration_status(self):
        """Gets the migration_status of this FolderWriteableResponse.  # noqa: E501

        Status of the root folder migration status from v1 to v2  # noqa: E501

        :return: The migration_status of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._migration_status

    @migration_status.setter
    def migration_status(self, migration_status):
        """Sets the migration_status of this FolderWriteableResponse.

        Status of the root folder migration status from v1 to v2  # noqa: E501

        :param migration_status: The migration_status of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._migration_status = migration_status

    @property
    def active_job_ids(self):
        """Gets the active_job_ids of this FolderWriteableResponse.  # noqa: E501

        List of Jobs in Pending and In Progress status  # noqa: E501

        :return: The active_job_ids of this FolderWriteableResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._active_job_ids

    @active_job_ids.setter
    def active_job_ids(self, active_job_ids):
        """Sets the active_job_ids of this FolderWriteableResponse.

        List of Jobs in Pending and In Progress status  # noqa: E501

        :param active_job_ids: The active_job_ids of this FolderWriteableResponse.  # noqa: E501
        :type: list[str]
        """

        self._active_job_ids = active_job_ids

    @property
    def copy_job_id(self):
        """Gets the copy_job_id of this FolderWriteableResponse.  # noqa: E501

        Job that copied the folder  # noqa: E501

        :return: The copy_job_id of this FolderWriteableResponse.  # noqa: E501
        :rtype: str
        """
        return self._copy_job_id

    @copy_job_id.setter
    def copy_job_id(self, copy_job_id):
        """Sets the copy_job_id of this FolderWriteableResponse.

        Job that copied the folder  # noqa: E501

        :param copy_job_id: The copy_job_id of this FolderWriteableResponse.  # noqa: E501
        :type: str
        """

        self._copy_job_id = copy_job_id

    @property
    def object_store_access(self):
        """Gets the object_store_access of this FolderWriteableResponse.  # noqa: E501


        :return: The object_store_access of this FolderWriteableResponse.  # noqa: E501
        :rtype: ObjectStoreAccess
        """
        return self._object_store_access

    @object_store_access.setter
    def object_store_access(self, object_store_access):
        """Sets the object_store_access of this FolderWriteableResponse.


        :param object_store_access: The object_store_access of this FolderWriteableResponse.  # noqa: E501
        :type: ObjectStoreAccess
        """

        self._object_store_access = object_store_access

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FolderWriteableResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FolderWriteableResponse):
            return True

        return self.to_dict() != other.to_dict()



# -*- coding: utf-8 -*-
"""wes module

ImplNote:
Consider implementation here should be reusable application specific routines for WES common use cases.
Consider not to re-do libwes SDK generality.
"""
import logging

from libumccr import libjson

from libica.app import configuration
from libica.openapi import libwes

logger = logging.getLogger(__name__)


def get_run(wfr_id, to_dict=False, to_json=False):
    """
    Get workflow run from WES endpoint ala `ica workflows runs get wfr.81cf25dxxx`

    :param wfr_id:
    :param to_json: False by default
    :param to_dict: False by default
    :return: instance of libwes.WorkflowRun unless to_dict or to_json
    """

    with libwes.ApiClient(configuration(libwes)) as api_client:
        run_api = libwes.WorkflowRunsApi(api_client)
        try:
            logger.info(f"Getting '{wfr_id}' from WES RUN API endpoint")
            wfl_run: libwes.WorkflowRun = run_api.get_workflow_run(run_id=wfr_id)

            if to_dict:
                return wfl_run.to_dict()

            elif to_json:
                return libjson.dumps(wfl_run.to_dict())

            return wfl_run
        except libwes.ApiException as e:
            logger.error(f"Exception when calling get_workflow_run: \n{e}")



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class VolumeResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'tenant_id': 'str',
        'sub_tenant_id': 'str',
        'urn': 'str',
        'root_folder_id': 'str',
        'root_key_prefix': 'str',
        'volume_configuration_name': 'str',
        'inherited_acl': 'list[str]',
        'time_created': 'datetime',
        'created_by': 'str',
        'time_modified': 'datetime',
        'modified_by': 'str',
        'job_status': 'JobStatus',
        'metadata': 'object',
        'life_cycle': 'VolumeLifeCycleSettings',
        'migration_status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'tenant_id': 'tenantId',
        'sub_tenant_id': 'subTenantId',
        'urn': 'urn',
        'root_folder_id': 'rootFolderId',
        'root_key_prefix': 'rootKeyPrefix',
        'volume_configuration_name': 'volumeConfigurationName',
        'inherited_acl': 'inheritedAcl',
        'time_created': 'timeCreated',
        'created_by': 'createdBy',
        'time_modified': 'timeModified',
        'modified_by': 'modifiedBy',
        'job_status': 'jobStatus',
        'metadata': 'metadata',
        'life_cycle': 'lifeCycle',
        'migration_status': 'migrationStatus'
    }

    def __init__(self, id=None, name=None, tenant_id=None, sub_tenant_id=None, urn=None, root_folder_id=None, root_key_prefix=None, volume_configuration_name=None, inherited_acl=None, time_created=None, created_by=None, time_modified=None, modified_by=None, job_status=None, metadata=None, life_cycle=None, migration_status=None, local_vars_configuration=None):  # noqa: E501
        """VolumeResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._tenant_id = None
        self._sub_tenant_id = None
        self._urn = None
        self._root_folder_id = None
        self._root_key_prefix = None
        self._volume_configuration_name = None
        self._inherited_acl = None
        self._time_created = None
        self._created_by = None
        self._time_modified = None
        self._modified_by = None
        self._job_status = None
        self._metadata = None
        self._life_cycle = None
        self._migration_status = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if sub_tenant_id is not None:
            self.sub_tenant_id = sub_tenant_id
        if urn is not None:
            self.urn = urn
        if root_folder_id is not None:
            self.root_folder_id = root_folder_id
        if root_key_prefix is not None:
            self.root_key_prefix = root_key_prefix
        if volume_configuration_name is not None:
            self.volume_configuration_name = volume_configuration_name
        if inherited_acl is not None:
            self.inherited_acl = inherited_acl
        if time_created is not None:
            self.time_created = time_created
        if created_by is not None:
            self.created_by = created_by
        if time_modified is not None:
            self.time_modified = time_modified
        if modified_by is not None:
            self.modified_by = modified_by
        if job_status is not None:
            self.job_status = job_status
        if metadata is not None:
            self.metadata = metadata
        if life_cycle is not None:
            self.life_cycle = life_cycle
        if migration_status is not None:
            self.migration_status = migration_status

    @property
    def id(self):
        """Gets the id of this VolumeResponse.  # noqa: E501

        A unique identifier for this Volume  # noqa: E501

        :return: The id of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VolumeResponse.

        A unique identifier for this Volume  # noqa: E501

        :param id: The id of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this VolumeResponse.  # noqa: E501

        The name of this Volume  # noqa: E501

        :return: The name of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VolumeResponse.

        The name of this Volume  # noqa: E501

        :param name: The name of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def tenant_id(self):
        """Gets the tenant_id of this VolumeResponse.  # noqa: E501

        The unique identifier for this Volume's Tenant  # noqa: E501

        :return: The tenant_id of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this VolumeResponse.

        The unique identifier for this Volume's Tenant  # noqa: E501

        :param tenant_id: The tenant_id of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def sub_tenant_id(self):
        """Gets the sub_tenant_id of this VolumeResponse.  # noqa: E501

        The unique identifier for this Volume's Sub Tenant  # noqa: E501

        :return: The sub_tenant_id of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._sub_tenant_id

    @sub_tenant_id.setter
    def sub_tenant_id(self, sub_tenant_id):
        """Sets the sub_tenant_id of this VolumeResponse.

        The unique identifier for this Volume's Sub Tenant  # noqa: E501

        :param sub_tenant_id: The sub_tenant_id of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._sub_tenant_id = sub_tenant_id

    @property
    def urn(self):
        """Gets the urn of this VolumeResponse.  # noqa: E501

        The Universal Resource Name, unique to this Volume  # noqa: E501

        :return: The urn of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this VolumeResponse.

        The Universal Resource Name, unique to this Volume  # noqa: E501

        :param urn: The urn of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def root_folder_id(self):
        """Gets the root_folder_id of this VolumeResponse.  # noqa: E501

        The unique identifier for the root Folder of this Volume  # noqa: E501

        :return: The root_folder_id of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._root_folder_id

    @root_folder_id.setter
    def root_folder_id(self, root_folder_id):
        """Sets the root_folder_id of this VolumeResponse.

        The unique identifier for the root Folder of this Volume  # noqa: E501

        :param root_folder_id: The root_folder_id of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._root_folder_id = root_folder_id

    @property
    def root_key_prefix(self):
        """Gets the root_key_prefix of this VolumeResponse.  # noqa: E501

        The base bucket location for Volumes associated with custom VolumeConfigurations otherwise this field is not set.  # noqa: E501

        :return: The root_key_prefix of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._root_key_prefix

    @root_key_prefix.setter
    def root_key_prefix(self, root_key_prefix):
        """Sets the root_key_prefix of this VolumeResponse.

        The base bucket location for Volumes associated with custom VolumeConfigurations otherwise this field is not set.  # noqa: E501

        :param root_key_prefix: The root_key_prefix of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._root_key_prefix = root_key_prefix

    @property
    def volume_configuration_name(self):
        """Gets the volume_configuration_name of this VolumeResponse.  # noqa: E501

        Unique name of the Volume configuration for this Volume.  This field will only be set if a custom Volume configuration is associated.  # noqa: E501

        :return: The volume_configuration_name of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._volume_configuration_name

    @volume_configuration_name.setter
    def volume_configuration_name(self, volume_configuration_name):
        """Sets the volume_configuration_name of this VolumeResponse.

        Unique name of the Volume configuration for this Volume.  This field will only be set if a custom Volume configuration is associated.  # noqa: E501

        :param volume_configuration_name: The volume_configuration_name of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._volume_configuration_name = volume_configuration_name

    @property
    def inherited_acl(self):
        """Gets the inherited_acl of this VolumeResponse.  # noqa: E501

        The inherited list of Id(s) that have access to this Volume  # noqa: E501

        :return: The inherited_acl of this VolumeResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._inherited_acl

    @inherited_acl.setter
    def inherited_acl(self, inherited_acl):
        """Sets the inherited_acl of this VolumeResponse.

        The inherited list of Id(s) that have access to this Volume  # noqa: E501

        :param inherited_acl: The inherited_acl of this VolumeResponse.  # noqa: E501
        :type: list[str]
        """

        self._inherited_acl = inherited_acl

    @property
    def time_created(self):
        """Gets the time_created of this VolumeResponse.  # noqa: E501

        The date & time this Volume was created, in GDS  # noqa: E501

        :return: The time_created of this VolumeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this VolumeResponse.

        The date & time this Volume was created, in GDS  # noqa: E501

        :param time_created: The time_created of this VolumeResponse.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def created_by(self):
        """Gets the created_by of this VolumeResponse.  # noqa: E501

        The creator of this Volume  # noqa: E501

        :return: The created_by of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this VolumeResponse.

        The creator of this Volume  # noqa: E501

        :param created_by: The created_by of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def time_modified(self):
        """Gets the time_modified of this VolumeResponse.  # noqa: E501

        The date & time this Volume was updated, in GDS  # noqa: E501

        :return: The time_modified of this VolumeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this VolumeResponse.

        The date & time this Volume was updated, in GDS  # noqa: E501

        :param time_modified: The time_modified of this VolumeResponse.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def modified_by(self):
        """Gets the modified_by of this VolumeResponse.  # noqa: E501

        The updator of this Volume  # noqa: E501

        :return: The modified_by of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this VolumeResponse.

        The updator of this Volume  # noqa: E501

        :param modified_by: The modified_by of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def job_status(self):
        """Gets the job_status of this VolumeResponse.  # noqa: E501


        :return: The job_status of this VolumeResponse.  # noqa: E501
        :rtype: JobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this VolumeResponse.


        :param job_status: The job_status of this VolumeResponse.  # noqa: E501
        :type: JobStatus
        """

        self._job_status = job_status

    @property
    def metadata(self):
        """Gets the metadata of this VolumeResponse.  # noqa: E501

        Metadata about this Volume  # noqa: E501

        :return: The metadata of this VolumeResponse.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this VolumeResponse.

        Metadata about this Volume  # noqa: E501

        :param metadata: The metadata of this VolumeResponse.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def life_cycle(self):
        """Gets the life_cycle of this VolumeResponse.  # noqa: E501


        :return: The life_cycle of this VolumeResponse.  # noqa: E501
        :rtype: VolumeLifeCycleSettings
        """
        return self._life_cycle

    @life_cycle.setter
    def life_cycle(self, life_cycle):
        """Sets the life_cycle of this VolumeResponse.


        :param life_cycle: The life_cycle of this VolumeResponse.  # noqa: E501
        :type: VolumeLifeCycleSettings
        """

        self._life_cycle = life_cycle

    @property
    def migration_status(self):
        """Gets the migration_status of this VolumeResponse.  # noqa: E501

        Status of the root folder migration status from v1 to v2  # noqa: E501

        :return: The migration_status of this VolumeResponse.  # noqa: E501
        :rtype: str
        """
        return self._migration_status

    @migration_status.setter
    def migration_status(self, migration_status):
        """Sets the migration_status of this VolumeResponse.

        Status of the root folder migration status from v1 to v2  # noqa: E501

        :param migration_status: The migration_status of this VolumeResponse.  # noqa: E501
        :type: str
        """

        self._migration_status = migration_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VolumeResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class PartInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'part': 'int',
        'date': 'str',
        'date_time': 'str',
        'signature': 'str'
    }

    attribute_map = {
        'part': 'part',
        'date': 'date',
        'date_time': 'dateTime',
        'signature': 'signature'
    }

    def __init__(self, part=None, date=None, date_time=None, signature=None, local_vars_configuration=None):  # noqa: E501
        """PartInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._part = None
        self._date = None
        self._date_time = None
        self._signature = None
        self.discriminator = None

        if part is not None:
            self.part = part
        if date is not None:
            self.date = date
        if date_time is not None:
            self.date_time = date_time
        if signature is not None:
            self.signature = signature

    @property
    def part(self):
        """Gets the part of this PartInfo.  # noqa: E501

        Part number to be applied to {part} in MultipartTemplate  # noqa: E501

        :return: The part of this PartInfo.  # noqa: E501
        :rtype: int
        """
        return self._part

    @part.setter
    def part(self, part):
        """Sets the part of this PartInfo.

        Part number to be applied to {part} in MultipartTemplate  # noqa: E501

        :param part: The part of this PartInfo.  # noqa: E501
        :type: int
        """

        self._part = part

    @property
    def date(self):
        """Gets the date of this PartInfo.  # noqa: E501

        Date to be applied to {date} in MultipartTemplate  # noqa: E501

        :return: The date of this PartInfo.  # noqa: E501
        :rtype: str
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this PartInfo.

        Date to be applied to {date} in MultipartTemplate  # noqa: E501

        :param date: The date of this PartInfo.  # noqa: E501
        :type: str
        """

        self._date = date

    @property
    def date_time(self):
        """Gets the date_time of this PartInfo.  # noqa: E501

        DateTime to be applied to {datetime} in MultipartTemplate  # noqa: E501

        :return: The date_time of this PartInfo.  # noqa: E501
        :rtype: str
        """
        return self._date_time

    @date_time.setter
    def date_time(self, date_time):
        """Sets the date_time of this PartInfo.

        DateTime to be applied to {datetime} in MultipartTemplate  # noqa: E501

        :param date_time: The date_time of this PartInfo.  # noqa: E501
        :type: str
        """

        self._date_time = date_time

    @property
    def signature(self):
        """Gets the signature of this PartInfo.  # noqa: E501

        Signature to be applied to {signature} in MultipartTemplate  # noqa: E501

        :return: The signature of this PartInfo.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this PartInfo.

        Signature to be applied to {signature} in MultipartTemplate  # noqa: E501

        :param signature: The signature of this PartInfo.  # noqa: E501
        :type: str
        """

        self._signature = signature

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libtes.configuration import Configuration


class AgentTaskRun(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'href': 'str',
        'urn': 'str',
        'nonce': 'str',
        'encryption_key': 'str',
        'input_manifest_url': 'str',
        'output_manifest_url': 'str',
        'heartbeat_manifest_url': 'str',
        'output_token_manifest_url': 'str',
        'name': 'str',
        'description': 'str',
        'status': 'str',
        'status_details': 'str',
        'type_of_resource': 'str',
        'size_of_resource': 'str',
        'tier_of_resource': 'str',
        'execution': 'Execution',
        'task_version_summary': 'TaskVersionSummary',
        'logs': 'list[TaskRunLogs]',
        'execution_raw_json': 'str',
        'acl': 'list[str]',
        'tenant_id': 'str',
        'sub_tenant_id': 'str',
        'created_by': 'str',
        'time_created': 'datetime',
        'modified_by': 'str',
        'time_modified': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'href': 'href',
        'urn': 'urn',
        'nonce': 'nonce',
        'encryption_key': 'encryptionKey',
        'input_manifest_url': 'inputManifestUrl',
        'output_manifest_url': 'outputManifestUrl',
        'heartbeat_manifest_url': 'heartbeatManifestUrl',
        'output_token_manifest_url': 'outputTokenManifestUrl',
        'name': 'name',
        'description': 'description',
        'status': 'status',
        'status_details': 'statusDetails',
        'type_of_resource': 'typeOfResource',
        'size_of_resource': 'sizeOfResource',
        'tier_of_resource': 'tierOfResource',
        'execution': 'execution',
        'task_version_summary': 'taskVersionSummary',
        'logs': 'logs',
        'execution_raw_json': 'executionRawJson',
        'acl': 'acl',
        'tenant_id': 'tenantId',
        'sub_tenant_id': 'subTenantId',
        'created_by': 'createdBy',
        'time_created': 'timeCreated',
        'modified_by': 'modifiedBy',
        'time_modified': 'timeModified'
    }

    def __init__(self, id=None, href=None, urn=None, nonce=None, encryption_key=None, input_manifest_url=None, output_manifest_url=None, heartbeat_manifest_url=None, output_token_manifest_url=None, name=None, description=None, status='Pending', status_details=None, type_of_resource=None, size_of_resource=None, tier_of_resource=None, execution=None, task_version_summary=None, logs=None, execution_raw_json=None, acl=None, tenant_id=None, sub_tenant_id=None, created_by=None, time_created=None, modified_by=None, time_modified=None, local_vars_configuration=None):  # noqa: E501
        """AgentTaskRun - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._href = None
        self._urn = None
        self._nonce = None
        self._encryption_key = None
        self._input_manifest_url = None
        self._output_manifest_url = None
        self._heartbeat_manifest_url = None
        self._output_token_manifest_url = None
        self._name = None
        self._description = None
        self._status = None
        self._status_details = None
        self._type_of_resource = None
        self._size_of_resource = None
        self._tier_of_resource = None
        self._execution = None
        self._task_version_summary = None
        self._logs = None
        self._execution_raw_json = None
        self._acl = None
        self._tenant_id = None
        self._sub_tenant_id = None
        self._created_by = None
        self._time_created = None
        self._modified_by = None
        self._time_modified = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if urn is not None:
            self.urn = urn
        if nonce is not None:
            self.nonce = nonce
        if encryption_key is not None:
            self.encryption_key = encryption_key
        if input_manifest_url is not None:
            self.input_manifest_url = input_manifest_url
        if output_manifest_url is not None:
            self.output_manifest_url = output_manifest_url
        if heartbeat_manifest_url is not None:
            self.heartbeat_manifest_url = heartbeat_manifest_url
        if output_token_manifest_url is not None:
            self.output_token_manifest_url = output_token_manifest_url
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if status is not None:
            self.status = status
        if status_details is not None:
            self.status_details = status_details
        if type_of_resource is not None:
            self.type_of_resource = type_of_resource
        if size_of_resource is not None:
            self.size_of_resource = size_of_resource
        if tier_of_resource is not None:
            self.tier_of_resource = tier_of_resource
        if execution is not None:
            self.execution = execution
        if task_version_summary is not None:
            self.task_version_summary = task_version_summary
        if logs is not None:
            self.logs = logs
        if execution_raw_json is not None:
            self.execution_raw_json = execution_raw_json
        if acl is not None:
            self.acl = acl
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if sub_tenant_id is not None:
            self.sub_tenant_id = sub_tenant_id
        if created_by is not None:
            self.created_by = created_by
        if time_created is not None:
            self.time_created = time_created
        if modified_by is not None:
            self.modified_by = modified_by
        if time_modified is not None:
            self.time_modified = time_modified

    @property
    def id(self):
        """Gets the id of this AgentTaskRun.  # noqa: E501

        Global identifier for object  # noqa: E501

        :return: The id of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AgentTaskRun.

        Global identifier for object  # noqa: E501

        :param id: The id of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this AgentTaskRun.  # noqa: E501

        Href of the object  # noqa: E501

        :return: The href of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this AgentTaskRun.

        Href of the object  # noqa: E501

        :param href: The href of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def urn(self):
        """Gets the urn of this AgentTaskRun.  # noqa: E501

        URN of the resource  # noqa: E501

        :return: The urn of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this AgentTaskRun.

        URN of the resource  # noqa: E501

        :param urn: The urn of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def nonce(self):
        """Gets the nonce of this AgentTaskRun.  # noqa: E501


        :return: The nonce of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._nonce

    @nonce.setter
    def nonce(self, nonce):
        """Sets the nonce of this AgentTaskRun.


        :param nonce: The nonce of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._nonce = nonce

    @property
    def encryption_key(self):
        """Gets the encryption_key of this AgentTaskRun.  # noqa: E501


        :return: The encryption_key of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._encryption_key

    @encryption_key.setter
    def encryption_key(self, encryption_key):
        """Sets the encryption_key of this AgentTaskRun.


        :param encryption_key: The encryption_key of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._encryption_key = encryption_key

    @property
    def input_manifest_url(self):
        """Gets the input_manifest_url of this AgentTaskRun.  # noqa: E501


        :return: The input_manifest_url of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._input_manifest_url

    @input_manifest_url.setter
    def input_manifest_url(self, input_manifest_url):
        """Sets the input_manifest_url of this AgentTaskRun.


        :param input_manifest_url: The input_manifest_url of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._input_manifest_url = input_manifest_url

    @property
    def output_manifest_url(self):
        """Gets the output_manifest_url of this AgentTaskRun.  # noqa: E501


        :return: The output_manifest_url of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._output_manifest_url

    @output_manifest_url.setter
    def output_manifest_url(self, output_manifest_url):
        """Sets the output_manifest_url of this AgentTaskRun.


        :param output_manifest_url: The output_manifest_url of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._output_manifest_url = output_manifest_url

    @property
    def heartbeat_manifest_url(self):
        """Gets the heartbeat_manifest_url of this AgentTaskRun.  # noqa: E501


        :return: The heartbeat_manifest_url of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._heartbeat_manifest_url

    @heartbeat_manifest_url.setter
    def heartbeat_manifest_url(self, heartbeat_manifest_url):
        """Sets the heartbeat_manifest_url of this AgentTaskRun.


        :param heartbeat_manifest_url: The heartbeat_manifest_url of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._heartbeat_manifest_url = heartbeat_manifest_url

    @property
    def output_token_manifest_url(self):
        """Gets the output_token_manifest_url of this AgentTaskRun.  # noqa: E501


        :return: The output_token_manifest_url of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._output_token_manifest_url

    @output_token_manifest_url.setter
    def output_token_manifest_url(self, output_token_manifest_url):
        """Sets the output_token_manifest_url of this AgentTaskRun.


        :param output_token_manifest_url: The output_token_manifest_url of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._output_token_manifest_url = output_token_manifest_url

    @property
    def name(self):
        """Gets the name of this AgentTaskRun.  # noqa: E501


        :return: The name of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AgentTaskRun.


        :param name: The name of this AgentTaskRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 0):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `0`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this AgentTaskRun.  # noqa: E501


        :return: The description of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AgentTaskRun.


        :param description: The description of this AgentTaskRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 4096):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `4096`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def status(self):
        """Gets the status of this AgentTaskRun.  # noqa: E501


        :return: The status of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AgentTaskRun.


        :param status: The status of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_details(self):
        """Gets the status_details of this AgentTaskRun.  # noqa: E501


        :return: The status_details of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._status_details

    @status_details.setter
    def status_details(self, status_details):
        """Sets the status_details of this AgentTaskRun.


        :param status_details: The status_details of this AgentTaskRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                status_details is not None and len(status_details) > 4096):
            raise ValueError("Invalid value for `status_details`, length must be less than or equal to `4096`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status_details is not None and len(status_details) < 0):
            raise ValueError("Invalid value for `status_details`, length must be greater than or equal to `0`")  # noqa: E501

        self._status_details = status_details

    @property
    def type_of_resource(self):
        """Gets the type_of_resource of this AgentTaskRun.  # noqa: E501


        :return: The type_of_resource of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._type_of_resource

    @type_of_resource.setter
    def type_of_resource(self, type_of_resource):
        """Sets the type_of_resource of this AgentTaskRun.


        :param type_of_resource: The type_of_resource of this AgentTaskRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                type_of_resource is not None and len(type_of_resource) > 255):
            raise ValueError("Invalid value for `type_of_resource`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                type_of_resource is not None and len(type_of_resource) < 0):
            raise ValueError("Invalid value for `type_of_resource`, length must be greater than or equal to `0`")  # noqa: E501

        self._type_of_resource = type_of_resource

    @property
    def size_of_resource(self):
        """Gets the size_of_resource of this AgentTaskRun.  # noqa: E501


        :return: The size_of_resource of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._size_of_resource

    @size_of_resource.setter
    def size_of_resource(self, size_of_resource):
        """Sets the size_of_resource of this AgentTaskRun.


        :param size_of_resource: The size_of_resource of this AgentTaskRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                size_of_resource is not None and len(size_of_resource) > 255):
            raise ValueError("Invalid value for `size_of_resource`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                size_of_resource is not None and len(size_of_resource) < 0):
            raise ValueError("Invalid value for `size_of_resource`, length must be greater than or equal to `0`")  # noqa: E501

        self._size_of_resource = size_of_resource

    @property
    def tier_of_resource(self):
        """Gets the tier_of_resource of this AgentTaskRun.  # noqa: E501


        :return: The tier_of_resource of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._tier_of_resource

    @tier_of_resource.setter
    def tier_of_resource(self, tier_of_resource):
        """Sets the tier_of_resource of this AgentTaskRun.


        :param tier_of_resource: The tier_of_resource of this AgentTaskRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                tier_of_resource is not None and len(tier_of_resource) > 255):
            raise ValueError("Invalid value for `tier_of_resource`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                tier_of_resource is not None and len(tier_of_resource) < 0):
            raise ValueError("Invalid value for `tier_of_resource`, length must be greater than or equal to `0`")  # noqa: E501

        self._tier_of_resource = tier_of_resource

    @property
    def execution(self):
        """Gets the execution of this AgentTaskRun.  # noqa: E501


        :return: The execution of this AgentTaskRun.  # noqa: E501
        :rtype: Execution
        """
        return self._execution

    @execution.setter
    def execution(self, execution):
        """Sets the execution of this AgentTaskRun.


        :param execution: The execution of this AgentTaskRun.  # noqa: E501
        :type: Execution
        """

        self._execution = execution

    @property
    def task_version_summary(self):
        """Gets the task_version_summary of this AgentTaskRun.  # noqa: E501


        :return: The task_version_summary of this AgentTaskRun.  # noqa: E501
        :rtype: TaskVersionSummary
        """
        return self._task_version_summary

    @task_version_summary.setter
    def task_version_summary(self, task_version_summary):
        """Sets the task_version_summary of this AgentTaskRun.


        :param task_version_summary: The task_version_summary of this AgentTaskRun.  # noqa: E501
        :type: TaskVersionSummary
        """

        self._task_version_summary = task_version_summary

    @property
    def logs(self):
        """Gets the logs of this AgentTaskRun.  # noqa: E501


        :return: The logs of this AgentTaskRun.  # noqa: E501
        :rtype: list[TaskRunLogs]
        """
        return self._logs

    @logs.setter
    def logs(self, logs):
        """Sets the logs of this AgentTaskRun.


        :param logs: The logs of this AgentTaskRun.  # noqa: E501
        :type: list[TaskRunLogs]
        """

        self._logs = logs

    @property
    def execution_raw_json(self):
        """Gets the execution_raw_json of this AgentTaskRun.  # noqa: E501


        :return: The execution_raw_json of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._execution_raw_json

    @execution_raw_json.setter
    def execution_raw_json(self, execution_raw_json):
        """Sets the execution_raw_json of this AgentTaskRun.


        :param execution_raw_json: The execution_raw_json of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._execution_raw_json = execution_raw_json

    @property
    def acl(self):
        """Gets the acl of this AgentTaskRun.  # noqa: E501

        Access Control List  # noqa: E501

        :return: The acl of this AgentTaskRun.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this AgentTaskRun.

        Access Control List  # noqa: E501

        :param acl: The acl of this AgentTaskRun.  # noqa: E501
        :type: list[str]
        """

        self._acl = acl

    @property
    def tenant_id(self):
        """Gets the tenant_id of this AgentTaskRun.  # noqa: E501


        :return: The tenant_id of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this AgentTaskRun.


        :param tenant_id: The tenant_id of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def sub_tenant_id(self):
        """Gets the sub_tenant_id of this AgentTaskRun.  # noqa: E501


        :return: The sub_tenant_id of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._sub_tenant_id

    @sub_tenant_id.setter
    def sub_tenant_id(self, sub_tenant_id):
        """Sets the sub_tenant_id of this AgentTaskRun.


        :param sub_tenant_id: The sub_tenant_id of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._sub_tenant_id = sub_tenant_id

    @property
    def created_by(self):
        """Gets the created_by of this AgentTaskRun.  # noqa: E501

        User who created the object  # noqa: E501

        :return: The created_by of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this AgentTaskRun.

        User who created the object  # noqa: E501

        :param created_by: The created_by of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def time_created(self):
        """Gets the time_created of this AgentTaskRun.  # noqa: E501

        Date and Time (in UTC) when object was created in TES  # noqa: E501

        :return: The time_created of this AgentTaskRun.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this AgentTaskRun.

        Date and Time (in UTC) when object was created in TES  # noqa: E501

        :param time_created: The time_created of this AgentTaskRun.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def modified_by(self):
        """Gets the modified_by of this AgentTaskRun.  # noqa: E501

        User who updated the object  # noqa: E501

        :return: The modified_by of this AgentTaskRun.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this AgentTaskRun.

        User who updated the object  # noqa: E501

        :param modified_by: The modified_by of this AgentTaskRun.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def time_modified(self):
        """Gets the time_modified of this AgentTaskRun.  # noqa: E501

        Date and Time (in UTC) when object was modified in TES  # noqa: E501

        :return: The time_modified of this AgentTaskRun.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this AgentTaskRun.

        Date and Time (in UTC) when object was modified in TES  # noqa: E501

        :param time_modified: The time_modified of this AgentTaskRun.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentTaskRun):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentTaskRun):
            return True

        return self.to_dict() != other.to_dict()



"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p>   # noqa: E501

    The version of the OpenAPI document: 3
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from libica.openapi.v2.api_client import ApiClient, Endpoint as _Endpoint
from libica.openapi.v2.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from libica.openapi.v2.model.bundle_data_paged_list import BundleDataPagedList
from libica.openapi.v2.model.problem import Problem


class BundleDataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_bundle_data_endpoint = _Endpoint(
            settings={
                'response_type': (BundleDataPagedList,),
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/bundles/{bundleId}/data',
                'operation_id': 'get_bundle_data',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'bundle_id',
                    'full_text',
                    'id',
                    'filename',
                    'filename_match_mode',
                    'file_path',
                    'file_path_match_mode',
                    'status',
                    'format_id',
                    'format_code',
                    'type',
                    'parent_folder_id',
                    'parent_folder_path',
                    'creation_date_after',
                    'creation_date_before',
                    'status_date_after',
                    'status_date_before',
                    'user_tag',
                    'user_tag_match_mode',
                    'run_input_tag',
                    'run_input_tag_match_mode',
                    'run_output_tag',
                    'run_output_tag_match_mode',
                    'connector_tag',
                    'connector_tag_match_mode',
                    'technical_tag',
                    'technical_tag_match_mode',
                    'not_in_run',
                    'not_linked_to_sample',
                    'instrument_run_id',
                    'page_offset',
                    'page_token',
                    'page_size',
                    'sort',
                ],
                'required': [
                    'bundle_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'filename_match_mode',
                    'file_path_match_mode',
                    'status',
                    'type',
                    'user_tag_match_mode',
                    'run_input_tag_match_mode',
                    'run_output_tag_match_mode',
                    'connector_tag_match_mode',
                    'technical_tag_match_mode',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('filename_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('file_path_match_mode',): {

                        "STARTS_WITH_CASE_INSENSITIVE": "STARTS_WITH_CASE_INSENSITIVE",
                        "FULL_CASE_INSENSITIVE": "FULL_CASE_INSENSITIVE"
                    },
                    ('status',): {

                        "PARTIAL": "PARTIAL",
                        "AVAILABLE": "AVAILABLE",
                        "ARCHIVING": "ARCHIVING",
                        "ARCHIVED": "ARCHIVED",
                        "UNARCHIVING": "UNARCHIVING",
                        "DELETING": "DELETING"
                    },
                    ('type',): {

                        "FILE": "FILE",
                        "FOLDER": "FOLDER"
                    },
                    ('user_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('run_input_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('run_output_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('connector_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                    ('technical_tag_match_mode',): {

                        "EXACT": "EXACT",
                        "EXCLUDE": "EXCLUDE",
                        "FUZZY": "FUZZY"
                    },
                },
                'openapi_types': {
                    'bundle_id':
                        (str,),
                    'full_text':
                        (str,),
                    'id':
                        (str,),
                    'filename':
                        (str,),
                    'filename_match_mode':
                        (str,),
                    'file_path':
                        (str,),
                    'file_path_match_mode':
                        (str,),
                    'status':
                        (str,),
                    'format_id':
                        (str,),
                    'format_code':
                        (str,),
                    'type':
                        (str,),
                    'parent_folder_id':
                        (str,),
                    'parent_folder_path':
                        (str,),
                    'creation_date_after':
                        (str,),
                    'creation_date_before':
                        (str,),
                    'status_date_after':
                        (str,),
                    'status_date_before':
                        (str,),
                    'user_tag':
                        (str,),
                    'user_tag_match_mode':
                        (str,),
                    'run_input_tag':
                        (str,),
                    'run_input_tag_match_mode':
                        (str,),
                    'run_output_tag':
                        (str,),
                    'run_output_tag_match_mode':
                        (str,),
                    'connector_tag':
                        (str,),
                    'connector_tag_match_mode':
                        (str,),
                    'technical_tag':
                        (str,),
                    'technical_tag_match_mode':
                        (str,),
                    'not_in_run':
                        (str,),
                    'not_linked_to_sample':
                        (str,),
                    'instrument_run_id':
                        ([str],),
                    'page_offset':
                        (str,),
                    'page_token':
                        (str,),
                    'page_size':
                        (str,),
                    'sort':
                        (str,),
                },
                'attribute_map': {
                    'bundle_id': 'bundleId',
                    'full_text': 'fullText',
                    'id': 'id',
                    'filename': 'filename',
                    'filename_match_mode': 'filenameMatchMode',
                    'file_path': 'filePath',
                    'file_path_match_mode': 'filePathMatchMode',
                    'status': 'status',
                    'format_id': 'formatId',
                    'format_code': 'formatCode',
                    'type': 'type',
                    'parent_folder_id': 'parentFolderId',
                    'parent_folder_path': 'parentFolderPath',
                    'creation_date_after': 'creationDateAfter',
                    'creation_date_before': 'creationDateBefore',
                    'status_date_after': 'statusDateAfter',
                    'status_date_before': 'statusDateBefore',
                    'user_tag': 'userTag',
                    'user_tag_match_mode': 'userTagMatchMode',
                    'run_input_tag': 'runInputTag',
                    'run_input_tag_match_mode': 'runInputTagMatchMode',
                    'run_output_tag': 'runOutputTag',
                    'run_output_tag_match_mode': 'runOutputTagMatchMode',
                    'connector_tag': 'connectorTag',
                    'connector_tag_match_mode': 'connectorTagMatchMode',
                    'technical_tag': 'technicalTag',
                    'technical_tag_match_mode': 'technicalTagMatchMode',
                    'not_in_run': 'notInRun',
                    'not_linked_to_sample': 'notLinkedToSample',
                    'instrument_run_id': 'instrumentRunId',
                    'page_offset': 'pageOffset',
                    'page_token': 'pageToken',
                    'page_size': 'pageSize',
                    'sort': 'sort',
                },
                'location_map': {
                    'bundle_id': 'path',
                    'full_text': 'query',
                    'id': 'query',
                    'filename': 'query',
                    'filename_match_mode': 'query',
                    'file_path': 'query',
                    'file_path_match_mode': 'query',
                    'status': 'query',
                    'format_id': 'query',
                    'format_code': 'query',
                    'type': 'query',
                    'parent_folder_id': 'query',
                    'parent_folder_path': 'query',
                    'creation_date_after': 'query',
                    'creation_date_before': 'query',
                    'status_date_after': 'query',
                    'status_date_before': 'query',
                    'user_tag': 'query',
                    'user_tag_match_mode': 'query',
                    'run_input_tag': 'query',
                    'run_input_tag_match_mode': 'query',
                    'run_output_tag': 'query',
                    'run_output_tag_match_mode': 'query',
                    'connector_tag': 'query',
                    'connector_tag_match_mode': 'query',
                    'technical_tag': 'query',
                    'technical_tag_match_mode': 'query',
                    'not_in_run': 'query',
                    'not_linked_to_sample': 'query',
                    'instrument_run_id': 'query',
                    'page_offset': 'query',
                    'page_token': 'query',
                    'page_size': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                    'instrument_run_id': 'multi',
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json',
                    'application/vnd.illumina.v3+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.link_data_to_bundle_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/bundles/{bundleId}/data/{dataId}',
                'operation_id': 'link_data_to_bundle',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'bundle_id',
                    'data_id',
                ],
                'required': [
                    'bundle_id',
                    'data_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'bundle_id':
                        (str,),
                    'data_id':
                        (str,),
                },
                'attribute_map': {
                    'bundle_id': 'bundleId',
                    'data_id': 'dataId',
                },
                'location_map': {
                    'bundle_id': 'path',
                    'data_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.unlink_data_from_bundle_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth',
                    'JwtAuth'
                ],
                'endpoint_path': '/api/bundles/{bundleId}/data/{dataId}',
                'operation_id': 'unlink_data_from_bundle',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'bundle_id',
                    'data_id',
                ],
                'required': [
                    'bundle_id',
                    'data_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'bundle_id':
                        (str,),
                    'data_id':
                        (str,),
                },
                'attribute_map': {
                    'bundle_id': 'bundleId',
                    'data_id': 'dataId',
                },
                'location_map': {
                    'bundle_id': 'path',
                    'data_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/problem+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_bundle_data(
        self,
        bundle_id,
        **kwargs
    ):
        """Retrieve the list of bundle data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_bundle_data(bundle_id, async_req=True)
        >>> result = thread.get()

        Args:
            bundle_id (str):

        Keyword Args:
            full_text (str): To search through multiple fields of data.. [optional]
            id (str): The ids to filter on. This will always match exact.. [optional]
            filename (str): The filenames to filter on. The filenameMatchMode-parameter determines how the filtering is done.. [optional]
            filename_match_mode (str): How the filenames are filtered.. [optional]
            file_path (str): The paths of the files to filter on.. [optional]
            file_path_match_mode (str): How the file paths are filtered:   - STARTS_WITH_CASE_INSENSITIVE: Filters the file path to start with the value of the 'filePath' parameter, regardless of upper/lower casing. This allows e.g. listing all data in a folder and all it's sub-folders (recursively).  - FULL_CASE_INSENSITIVE: Filters the file path to fully match the value of the 'filePath' parameter, regardless of upper/lower casing. Note that this can result in multiple results if e.g. two files exist with the same filename but different casing (abc.txt and ABC.txt).. [optional] if omitted the server will use the default value of "STARTS_WITH_CASE_INSENSITIVE"
            status (str): The statuses to filter on.. [optional]
            format_id (str): The IDs of the formats to filter on.. [optional]
            format_code (str): The codes of the formats to filter on.. [optional]
            type (str): The type to filter on.. [optional]
            parent_folder_id (str): The IDs of parents folders to filter on. Lists all files and folders within the folder for the given ID, non-recursively.. [optional]
            parent_folder_path (str): The full path of the parent folder. Should start and end with a '/'. Lists all files and folders within the folder for the given path, non-recursively. This can be used to browse through the hierarchical tree of folders, e.g. traversing one level up can be done by removing the last part of the path.. [optional]
            creation_date_after (str): The date after which the data is created. Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            creation_date_before (str): The date before which the data is created. Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            status_date_after (str): The date after which the status has been updated. Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            status_date_before (str): The date before which the status has been updated Format: yyyy-MM-dd'T'HH:mm:ss'Z' eg: 2021-01-30T08:30:00Z. [optional]
            user_tag (str): The usertags to filter on. The userTagMatchMode-parameter determines how the filtering is done.. [optional]
            user_tag_match_mode (str): How the usertags are filtered.. [optional]
            run_input_tag (str): The runInputTags to filter on. The runInputTagMatchMode-parameter determines how the filtering is done.. [optional]
            run_input_tag_match_mode (str): How the runInputTags are filtered.. [optional]
            run_output_tag (str): The runOutputTags to filter on. The runOutputTagMatchMode-parameter determines how the filtering is done.. [optional]
            run_output_tag_match_mode (str): How the runOutputTags are filtered.. [optional]
            connector_tag (str): The connectorTags to filter on. The connectorTagMatchMode-parameter determines how the filtering is done.. [optional]
            connector_tag_match_mode (str): How the connectorTags are filtered.. [optional]
            technical_tag (str): The technicalTags to filter on. The techTagMatchMode-parameter determines how the filtering is done.. [optional]
            technical_tag_match_mode (str): How the technicalTags are filtered.. [optional]
            not_in_run (str): When set to true, the data will be filtered on data which is not used in a run.. [optional]
            not_linked_to_sample (str): When set to true only date that is unlinked to a sample will be returned.  This filter implies a filter of type File.. [optional]
            instrument_run_id ([str]): The instrument run IDs of the sequencing runs to filter on.. [optional]
            page_offset (str): [only use with offset-based paging]<br>The amount of rows to skip in the result. Ideally this is a multiple of the size parameter. Offset-based pagination has a result limit of 200K rows and does not guarantee unique results across pages. [optional]
            page_token (str): [only use with cursor-based paging]<br>The cursor to get subsequent results. The value to use is returned in the result when using cursor-based pagination. Cursor-based pagination guarantees complete and unique results across all pages.. [optional]
            page_size (str): [can be used with both offset- and cursor-based paging]<br>The amount of rows to return. Use in combination with the offset (when using offset-based pagination) or cursor (when using cursor-based pagination) parameter to get subsequent results. [optional]
            sort (str): [only use with offset-based paging]<br>Which field to order the results by. The default order is ascending, suffix with ' desc' to sort descending (suffix ' asc' also works for ascending). Multiple values should be separated with commas. An example: \"?sort=dateCreated, lastName desc\"  The attributes for which sorting is supported: - timeCreated - timeModified - name - path - fileSizeInBytes - status - format - dataType - willBeArchivedAt - willBeDeletedAt. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            BundleDataPagedList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['bundle_id'] = \
            bundle_id
        return self.get_bundle_data_endpoint.call_with_http_info(**kwargs)

    def link_data_to_bundle(
        self,
        bundle_id,
        data_id,
        **kwargs
    ):
        """Link data to this bundle.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.link_data_to_bundle(bundle_id, data_id, async_req=True)
        >>> result = thread.get()

        Args:
            bundle_id (str):
            data_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['bundle_id'] = \
            bundle_id
        kwargs['data_id'] = \
            data_id
        return self.link_data_to_bundle_endpoint.call_with_http_info(**kwargs)

    def unlink_data_from_bundle(
        self,
        bundle_id,
        data_id,
        **kwargs
    ):
        """Unlink data from this bundle.  # noqa: E501

        Note that for folders, this only unlinks the folder itself, not the folder contents!  Use 'Bundle Data Unlinking Batch' for recursive unlinking.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.unlink_data_from_bundle(bundle_id, data_id, async_req=True)
        >>> result = thread.get()

        Args:
            bundle_id (str):
            data_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['bundle_id'] = \
            bundle_id
        kwargs['data_id'] = \
            data_id
        return self.unlink_data_from_bundle_endpoint.call_with_http_info(**kwargs)




# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class AzureTemporaryReadOnlyCredentials(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'storage_account_name': 'str',
        'storage_container_name': 'str',
        'object_location': 'str',
        'region': 'str',
        'sas_token': 'str',
        'object_store_permissions': 'str',
        'expiration_date': 'datetime'
    }

    attribute_map = {
        'storage_account_name': 'storageAccountName',
        'storage_container_name': 'storageContainerName',
        'object_location': 'objectLocation',
        'region': 'region',
        'sas_token': 'sasToken',
        'object_store_permissions': 'objectStorePermissions',
        'expiration_date': 'expirationDate'
    }

    def __init__(self, storage_account_name=None, storage_container_name=None, object_location=None, region=None, sas_token=None, object_store_permissions=None, expiration_date=None, local_vars_configuration=None):  # noqa: E501
        """AzureTemporaryReadOnlyCredentials - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._storage_account_name = None
        self._storage_container_name = None
        self._object_location = None
        self._region = None
        self._sas_token = None
        self._object_store_permissions = None
        self._expiration_date = None
        self.discriminator = None

        if storage_account_name is not None:
            self.storage_account_name = storage_account_name
        if storage_container_name is not None:
            self.storage_container_name = storage_container_name
        if object_location is not None:
            self.object_location = object_location
        if region is not None:
            self.region = region
        if sas_token is not None:
            self.sas_token = sas_token
        if object_store_permissions is not None:
            self.object_store_permissions = object_store_permissions
        if expiration_date is not None:
            self.expiration_date = expiration_date

    @property
    def storage_account_name(self):
        """Gets the storage_account_name of this AzureTemporaryReadOnlyCredentials.  # noqa: E501


        :return: The storage_account_name of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :rtype: str
        """
        return self._storage_account_name

    @storage_account_name.setter
    def storage_account_name(self, storage_account_name):
        """Sets the storage_account_name of this AzureTemporaryReadOnlyCredentials.


        :param storage_account_name: The storage_account_name of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :type: str
        """

        self._storage_account_name = storage_account_name

    @property
    def storage_container_name(self):
        """Gets the storage_container_name of this AzureTemporaryReadOnlyCredentials.  # noqa: E501


        :return: The storage_container_name of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :rtype: str
        """
        return self._storage_container_name

    @storage_container_name.setter
    def storage_container_name(self, storage_container_name):
        """Sets the storage_container_name of this AzureTemporaryReadOnlyCredentials.


        :param storage_container_name: The storage_container_name of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :type: str
        """

        self._storage_container_name = storage_container_name

    @property
    def object_location(self):
        """Gets the object_location of this AzureTemporaryReadOnlyCredentials.  # noqa: E501


        :return: The object_location of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :rtype: str
        """
        return self._object_location

    @object_location.setter
    def object_location(self, object_location):
        """Sets the object_location of this AzureTemporaryReadOnlyCredentials.


        :param object_location: The object_location of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :type: str
        """

        self._object_location = object_location

    @property
    def region(self):
        """Gets the region of this AzureTemporaryReadOnlyCredentials.  # noqa: E501


        :return: The region of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this AzureTemporaryReadOnlyCredentials.


        :param region: The region of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def sas_token(self):
        """Gets the sas_token of this AzureTemporaryReadOnlyCredentials.  # noqa: E501


        :return: The sas_token of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :rtype: str
        """
        return self._sas_token

    @sas_token.setter
    def sas_token(self, sas_token):
        """Sets the sas_token of this AzureTemporaryReadOnlyCredentials.


        :param sas_token: The sas_token of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :type: str
        """

        self._sas_token = sas_token

    @property
    def object_store_permissions(self):
        """Gets the object_store_permissions of this AzureTemporaryReadOnlyCredentials.  # noqa: E501


        :return: The object_store_permissions of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :rtype: str
        """
        return self._object_store_permissions

    @object_store_permissions.setter
    def object_store_permissions(self, object_store_permissions):
        """Sets the object_store_permissions of this AzureTemporaryReadOnlyCredentials.


        :param object_store_permissions: The object_store_permissions of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :type: str
        """

        self._object_store_permissions = object_store_permissions

    @property
    def expiration_date(self):
        """Gets the expiration_date of this AzureTemporaryReadOnlyCredentials.  # noqa: E501


        :return: The expiration_date of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this AzureTemporaryReadOnlyCredentials.


        :param expiration_date: The expiration_date of this AzureTemporaryReadOnlyCredentials.  # noqa: E501
        :type: datetime
        """

        self._expiration_date = expiration_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AzureTemporaryReadOnlyCredentials):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AzureTemporaryReadOnlyCredentials):
            return True

        return self.to_dict() != other.to_dict()



from contextlib import closing
from typing import List

from libica.app import AppOps
from libica.openapi.v2 import ApiClient
from libica.openapi.v2.api.project_api import ProjectApi
from libica.openapi.v2.model.project import Project
from libica.openapi.v2.model.project_paged_list import ProjectPagedList


class ProjectOps(AppOps):

    def __init__(self, api_client: ApiClient = None):
        super(ProjectOps, self).__init__(api_client=api_client)

    def get_project_list(self) -> List[Project]:
        with closing(self.api_client) as ctx_api_client:
            project_api: ProjectApi = ProjectApi(api_client=ctx_api_client)
            project_list: ProjectPagedList = project_api.get_projects()
            return project_list.items

    def get_project_by_name(self, project_name) -> Project:
        for project in self.get_project_list():
            if project.name == project_name:
                return project

    def get_project_by_id(self, project_id) -> Project:
        with closing(self.api_client) as ctx_api_client:
            project_api: ProjectApi = ProjectApi(api_client=ctx_api_client)
            return project_api.get_project(project_id=project_id)



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class FileMoveOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'items_skipped_count': 'int',
        'items_failed_count': 'int',
        'items_moved_count': 'int',
        'folders_moved_count': 'int',
        'elastic_indexing_matched': 'bool',
        'items_failed': 'list[BulkFailedItem]'
    }

    attribute_map = {
        'items_skipped_count': 'itemsSkippedCount',
        'items_failed_count': 'itemsFailedCount',
        'items_moved_count': 'itemsMovedCount',
        'folders_moved_count': 'foldersMovedCount',
        'elastic_indexing_matched': 'elasticIndexingMatched',
        'items_failed': 'itemsFailed'
    }

    def __init__(self, items_skipped_count=None, items_failed_count=None, items_moved_count=None, folders_moved_count=None, elastic_indexing_matched=None, items_failed=None, local_vars_configuration=None):  # noqa: E501
        """FileMoveOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._items_skipped_count = None
        self._items_failed_count = None
        self._items_moved_count = None
        self._folders_moved_count = None
        self._elastic_indexing_matched = None
        self._items_failed = None
        self.discriminator = None

        if items_skipped_count is not None:
            self.items_skipped_count = items_skipped_count
        if items_failed_count is not None:
            self.items_failed_count = items_failed_count
        if items_moved_count is not None:
            self.items_moved_count = items_moved_count
        if folders_moved_count is not None:
            self.folders_moved_count = folders_moved_count
        if elastic_indexing_matched is not None:
            self.elastic_indexing_matched = elastic_indexing_matched
        if items_failed is not None:
            self.items_failed = items_failed

    @property
    def items_skipped_count(self):
        """Gets the items_skipped_count of this FileMoveOutput.  # noqa: E501


        :return: The items_skipped_count of this FileMoveOutput.  # noqa: E501
        :rtype: int
        """
        return self._items_skipped_count

    @items_skipped_count.setter
    def items_skipped_count(self, items_skipped_count):
        """Sets the items_skipped_count of this FileMoveOutput.


        :param items_skipped_count: The items_skipped_count of this FileMoveOutput.  # noqa: E501
        :type: int
        """

        self._items_skipped_count = items_skipped_count

    @property
    def items_failed_count(self):
        """Gets the items_failed_count of this FileMoveOutput.  # noqa: E501


        :return: The items_failed_count of this FileMoveOutput.  # noqa: E501
        :rtype: int
        """
        return self._items_failed_count

    @items_failed_count.setter
    def items_failed_count(self, items_failed_count):
        """Sets the items_failed_count of this FileMoveOutput.


        :param items_failed_count: The items_failed_count of this FileMoveOutput.  # noqa: E501
        :type: int
        """

        self._items_failed_count = items_failed_count

    @property
    def items_moved_count(self):
        """Gets the items_moved_count of this FileMoveOutput.  # noqa: E501


        :return: The items_moved_count of this FileMoveOutput.  # noqa: E501
        :rtype: int
        """
        return self._items_moved_count

    @items_moved_count.setter
    def items_moved_count(self, items_moved_count):
        """Sets the items_moved_count of this FileMoveOutput.


        :param items_moved_count: The items_moved_count of this FileMoveOutput.  # noqa: E501
        :type: int
        """

        self._items_moved_count = items_moved_count

    @property
    def folders_moved_count(self):
        """Gets the folders_moved_count of this FileMoveOutput.  # noqa: E501


        :return: The folders_moved_count of this FileMoveOutput.  # noqa: E501
        :rtype: int
        """
        return self._folders_moved_count

    @folders_moved_count.setter
    def folders_moved_count(self, folders_moved_count):
        """Sets the folders_moved_count of this FileMoveOutput.


        :param folders_moved_count: The folders_moved_count of this FileMoveOutput.  # noqa: E501
        :type: int
        """

        self._folders_moved_count = folders_moved_count

    @property
    def elastic_indexing_matched(self):
        """Gets the elastic_indexing_matched of this FileMoveOutput.  # noqa: E501


        :return: The elastic_indexing_matched of this FileMoveOutput.  # noqa: E501
        :rtype: bool
        """
        return self._elastic_indexing_matched

    @elastic_indexing_matched.setter
    def elastic_indexing_matched(self, elastic_indexing_matched):
        """Sets the elastic_indexing_matched of this FileMoveOutput.


        :param elastic_indexing_matched: The elastic_indexing_matched of this FileMoveOutput.  # noqa: E501
        :type: bool
        """

        self._elastic_indexing_matched = elastic_indexing_matched

    @property
    def items_failed(self):
        """Gets the items_failed of this FileMoveOutput.  # noqa: E501


        :return: The items_failed of this FileMoveOutput.  # noqa: E501
        :rtype: list[BulkFailedItem]
        """
        return self._items_failed

    @items_failed.setter
    def items_failed(self, items_failed):
        """Sets the items_failed of this FileMoveOutput.


        :param items_failed: The items_failed of this FileMoveOutput.  # noqa: E501
        :type: list[BulkFailedItem]
        """

        self._items_failed = items_failed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileMoveOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileMoveOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class CreateSessionResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'object_store_access': 'ObjectStoreAccess',
        'id': 'str',
        'folder_urn': 'str',
        'status': 'SessionStatus',
        'time_created': 'datetime',
        'time_credentials_expire': 'datetime',
        'time_closed': 'datetime',
        'time_completed': 'datetime',
        'metadata': 'object'
    }

    attribute_map = {
        'object_store_access': 'objectStoreAccess',
        'id': 'id',
        'folder_urn': 'folderUrn',
        'status': 'status',
        'time_created': 'timeCreated',
        'time_credentials_expire': 'timeCredentialsExpire',
        'time_closed': 'timeClosed',
        'time_completed': 'timeCompleted',
        'metadata': 'metadata'
    }

    def __init__(self, object_store_access=None, id=None, folder_urn=None, status=None, time_created=None, time_credentials_expire=None, time_closed=None, time_completed=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """CreateSessionResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._object_store_access = None
        self._id = None
        self._folder_urn = None
        self._status = None
        self._time_created = None
        self._time_credentials_expire = None
        self._time_closed = None
        self._time_completed = None
        self._metadata = None
        self.discriminator = None

        if object_store_access is not None:
            self.object_store_access = object_store_access
        if id is not None:
            self.id = id
        if folder_urn is not None:
            self.folder_urn = folder_urn
        if status is not None:
            self.status = status
        if time_created is not None:
            self.time_created = time_created
        if time_credentials_expire is not None:
            self.time_credentials_expire = time_credentials_expire
        if time_closed is not None:
            self.time_closed = time_closed
        if time_completed is not None:
            self.time_completed = time_completed
        if metadata is not None:
            self.metadata = metadata

    @property
    def object_store_access(self):
        """Gets the object_store_access of this CreateSessionResponse.  # noqa: E501


        :return: The object_store_access of this CreateSessionResponse.  # noqa: E501
        :rtype: ObjectStoreAccess
        """
        return self._object_store_access

    @object_store_access.setter
    def object_store_access(self, object_store_access):
        """Sets the object_store_access of this CreateSessionResponse.


        :param object_store_access: The object_store_access of this CreateSessionResponse.  # noqa: E501
        :type: ObjectStoreAccess
        """

        self._object_store_access = object_store_access

    @property
    def id(self):
        """Gets the id of this CreateSessionResponse.  # noqa: E501

        A unique identifier for this Session  # noqa: E501

        :return: The id of this CreateSessionResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CreateSessionResponse.

        A unique identifier for this Session  # noqa: E501

        :param id: The id of this CreateSessionResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def folder_urn(self):
        """Gets the folder_urn of this CreateSessionResponse.  # noqa: E501

        The Universal Resource Name of the Folder associated with the Session  # noqa: E501

        :return: The folder_urn of this CreateSessionResponse.  # noqa: E501
        :rtype: str
        """
        return self._folder_urn

    @folder_urn.setter
    def folder_urn(self, folder_urn):
        """Sets the folder_urn of this CreateSessionResponse.

        The Universal Resource Name of the Folder associated with the Session  # noqa: E501

        :param folder_urn: The folder_urn of this CreateSessionResponse.  # noqa: E501
        :type: str
        """

        self._folder_urn = folder_urn

    @property
    def status(self):
        """Gets the status of this CreateSessionResponse.  # noqa: E501


        :return: The status of this CreateSessionResponse.  # noqa: E501
        :rtype: SessionStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CreateSessionResponse.


        :param status: The status of this CreateSessionResponse.  # noqa: E501
        :type: SessionStatus
        """

        self._status = status

    @property
    def time_created(self):
        """Gets the time_created of this CreateSessionResponse.  # noqa: E501

        The date & time this Session was created, in GDS  # noqa: E501

        :return: The time_created of this CreateSessionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this CreateSessionResponse.

        The date & time this Session was created, in GDS  # noqa: E501

        :param time_created: The time_created of this CreateSessionResponse.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def time_credentials_expire(self):
        """Gets the time_credentials_expire of this CreateSessionResponse.  # noqa: E501

        The date & time this upload session expires  # noqa: E501

        :return: The time_credentials_expire of this CreateSessionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_credentials_expire

    @time_credentials_expire.setter
    def time_credentials_expire(self, time_credentials_expire):
        """Sets the time_credentials_expire of this CreateSessionResponse.

        The date & time this upload session expires  # noqa: E501

        :param time_credentials_expire: The time_credentials_expire of this CreateSessionResponse.  # noqa: E501
        :type: datetime
        """

        self._time_credentials_expire = time_credentials_expire

    @property
    def time_closed(self):
        """Gets the time_closed of this CreateSessionResponse.  # noqa: E501

        The date & time this Session was closed, in GDS  # noqa: E501

        :return: The time_closed of this CreateSessionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_closed

    @time_closed.setter
    def time_closed(self, time_closed):
        """Sets the time_closed of this CreateSessionResponse.

        The date & time this Session was closed, in GDS  # noqa: E501

        :param time_closed: The time_closed of this CreateSessionResponse.  # noqa: E501
        :type: datetime
        """

        self._time_closed = time_closed

    @property
    def time_completed(self):
        """Gets the time_completed of this CreateSessionResponse.  # noqa: E501

        The date & time this Session was completed, in GDS  # noqa: E501

        :return: The time_completed of this CreateSessionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._time_completed

    @time_completed.setter
    def time_completed(self, time_completed):
        """Sets the time_completed of this CreateSessionResponse.

        The date & time this Session was completed, in GDS  # noqa: E501

        :param time_completed: The time_completed of this CreateSessionResponse.  # noqa: E501
        :type: datetime
        """

        self._time_completed = time_completed

    @property
    def metadata(self):
        """Gets the metadata of this CreateSessionResponse.  # noqa: E501


        :return: The metadata of this CreateSessionResponse.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CreateSessionResponse.


        :param metadata: The metadata of this CreateSessionResponse.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSessionResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateSessionResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libtes.configuration import Configuration


class UpdateTaskRunStateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'status_details': 'str',
        'start_time': 'datetime',
        'completion_time': 'datetime'
    }

    attribute_map = {
        'status': 'status',
        'status_details': 'statusDetails',
        'start_time': 'startTime',
        'completion_time': 'completionTime'
    }

    def __init__(self, status=None, status_details=None, start_time=None, completion_time=None, local_vars_configuration=None):  # noqa: E501
        """UpdateTaskRunStateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._status_details = None
        self._start_time = None
        self._completion_time = None
        self.discriminator = None

        if status is not None:
            self.status = status
        if status_details is not None:
            self.status_details = status_details
        if start_time is not None:
            self.start_time = start_time
        if completion_time is not None:
            self.completion_time = completion_time

    @property
    def status(self):
        """Gets the status of this UpdateTaskRunStateRequest.  # noqa: E501

        New TaskRun status to be updated  # noqa: E501

        :return: The status of this UpdateTaskRunStateRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateTaskRunStateRequest.

        New TaskRun status to be updated  # noqa: E501

        :param status: The status of this UpdateTaskRunStateRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["CheckedOut", "Runnable", "Running", "Finalizing", "Completed", "FailedRestartable", "Failed", "Aborted", "TimedOut"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def status_details(self):
        """Gets the status_details of this UpdateTaskRunStateRequest.  # noqa: E501

        Description of the event that triggered the state change  # noqa: E501

        :return: The status_details of this UpdateTaskRunStateRequest.  # noqa: E501
        :rtype: str
        """
        return self._status_details

    @status_details.setter
    def status_details(self, status_details):
        """Sets the status_details of this UpdateTaskRunStateRequest.

        Description of the event that triggered the state change  # noqa: E501

        :param status_details: The status_details of this UpdateTaskRunStateRequest.  # noqa: E501
        :type: str
        """

        self._status_details = status_details

    @property
    def start_time(self):
        """Gets the start_time of this UpdateTaskRunStateRequest.  # noqa: E501

        TaskRun execution start time  # noqa: E501

        :return: The start_time of this UpdateTaskRunStateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this UpdateTaskRunStateRequest.

        TaskRun execution start time  # noqa: E501

        :param start_time: The start_time of this UpdateTaskRunStateRequest.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def completion_time(self):
        """Gets the completion_time of this UpdateTaskRunStateRequest.  # noqa: E501

        TaskRun execution completion time  # noqa: E501

        :return: The completion_time of this UpdateTaskRunStateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this UpdateTaskRunStateRequest.

        TaskRun execution completion time  # noqa: E501

        :param completion_time: The completion_time of this UpdateTaskRunStateRequest.  # noqa: E501
        :type: datetime
        """

        self._completion_time = completion_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTaskRunStateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateTaskRunStateRequest):
            return True

        return self.to_dict() != other.to_dict()
